@@ -1,37 +1,27 @@
 package MooseX::SemiAffordanceAccessor;
+BEGIN {
+  $MooseX::SemiAffordanceAccessor::VERSION = '0.06';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
-
-use Moose 0.84 ();
+use Moose 0.94 ();
 use Moose::Exporter;
 use Moose::Util::MetaRole;
 use MooseX::SemiAffordanceAccessor::Role::Attribute;
 
-# The main reason to use this is to ensure that we get the right value
-# in $p{for_class} later.
-Moose::Exporter->setup_import_methods();
-
-sub init_meta
-{
-    shift;
-    my %p = @_;
-
-    Moose->init_meta(%p);
-
-    return
-        Moose::Util::MetaRole::apply_metaclass_roles
-            ( for_class => $p{for_class},
-              attribute_metaclass_roles =>
-              ['MooseX::SemiAffordanceAccessor::Role::Attribute'],
-            );
-}
+Moose::Exporter->setup_import_methods(
+    class_metaroles => {
+        attribute => ['MooseX::SemiAffordanceAccessor::Role::Attribute'],
+    },
+);
 
 1;
 
-__END__
+# ABSTRACT: Name your accessors foo() and set_foo()
+
+
 
 =pod
 
@@ -39,6 +29,10 @@ __END__
 
 MooseX::SemiAffordanceAccessor - Name your accessors foo() and set_foo()
 
+=head1 VERSION
+
+version 0.06
+
 =head1 SYNOPSIS
 
     use MooseX::SemiAffordanceAccessor;
@@ -62,10 +56,6 @@ attribute, then that attribute's naming scheme is left unchanged.
 The name "semi-affordance" comes from David Wheeler's Class::Meta
 module.
 
-=head1 AUTHOR
-
-Dave Rolsky, C<< <autarch@urth.org> >>
-
 =head1 BUGS
 
 Please report any bugs or feature requests to
@@ -74,11 +64,20 @@ the web interface at L<http://rt.cpan.org>.  I will be notified, and
 then you'll automatically be notified of progress on your bug as I
 make changes.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2007-2008 Dave Rolsky, All Rights Reserved.
+  Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
